

[![image](https://img.shields.io/travis/TankerHQ/cloudmesh-slurm.svg?branch=main)](https://travis-ci.org/TankerHQ/cloudmesn-slurm)

[![image](https://img.shields.io/pypi/pyversions/cloudmesh-slurm.svg)](https://pypi.org/project/cloudmesh-slurm)

[![image](https://img.shields.io/pypi/v/cloudmesh-slurm.svg)](https://pypi.org/project/cloudmesh-slurm/)

[![image](https://img.shields.io/github/license/TankerHQ/python-cloudmesh-slurm.svg)](https://github.com/TankerHQ/python-cloudmeshslurm/blob/main/LICENSE)
